@@ -100,6 +100,10 @@ public Q_SLOTS:
      *  Starts new game
      */
     void startNewGame();
+    /**
+     * Ends game
+     */
+    void endGame();
     /**
      *  Ends current and starts next turn explicitly
      */
